---
{"dg-publish":true,"permalink":"/bookmarks/health-mind-and-so-on/occam-s-razor/","tags":["blog","brain","explanation","lifehack","mind","technique"]}
---


Part of [[Bookmarks/Health, Mind and so on/Mental Models General Intro\|Mental Models General Intro]]

# [How to Use Occam’s Razor Without Getting Cut](https://fs.blog/occams-razor/)

_Occam’s razor is one of the most useful, (yet misunderstood,) models in your mental toolbox to solve problems more quickly and efficiently. Here’s how to use it._

- [The Basics]()
- [The History of Occam’s Razor]()
- [Examples of the Use of Occam’s Razor]()

\*\*\*

Occam’s razor (also known as the “law of parsimony”) is a problem-solving principle which serves as a useful [mental model](https://fs.blog/mental-models/). A philosophical razor is a tool used to eliminate improbable options in a given situation. Occam’s is the best-known example.

Occam’s razor can be summarized as follows:

==_Among competing hypotheses, the one with the fewest assumptions should be selected._==

## The Basics

In simpler language, Occam’s razor states that **the simplest explanation is preferable to one that is more complex**. ==Simple theories are easier to verify. Simple solutions are easier to execute==.

In other words, we should avoid looking for excessively complex solutions to a problem, and focus on what works given the circumstances. Occam’s razor can be used in a wide range of situations, as a means of making rapid decisions and establishing truths without empirical evidence. It works best as a mental model for making initial conclusions before the full scope of information can be obtained.

Science and math offer interesting lessons that demonstrate the value of simplicity. For example, ==[the principle of minimum energy](https://en.wikipedia.org/wiki/Principle_of_minimum_energy) supports Occam’s razor.== This facet of the second law of thermodynamics states that wherever possible, the use of energy is minimized. Physicists use Occam’s razor in the knowledge that they can rely on everything to use the minimum energy necessary to function. A ball at the top of a hill will roll down in order to be at the point of minimum potential energy. The same principle is present in biology. If a person repeats the same action on a regular basis in response to the same cue and reward, it will become a habit as the corresponding neural pathway is formed. From then on, their brain will use less energy to complete the same action.

## The History of Occam’s Razor

The concept of Occam’s razor is credited to William of Ockham, a 14th-century friar, philosopher, and theologian. While he did not coin the term, his characteristic way of making deductions inspired other writers to develop the heuristic. Indeed, the concept of Occam’s razor is an ancient one. Aristotle produced the oldest known statement of the concept, saying, ==“We may assume the superiority, other things being equal, of the demonstration which derives from fewer postulates or hypotheses.”==

Robert Grosseteste expanded on Aristotle’s writing in the 1200s, declaring

> That is better and more valuable which requires fewer, other circumstances being equal…. For if one thing were demonstrated from many and another thing from fewer equally known premises, clearly that is better which is from fewer because it makes us know quickly, just as a universal demonstration is better than particular because it produces knowledge from fewer premises. Similarly, in natural science, in moral science, and in metaphysics the best is that which needs no premises and the better that which needs the fewer, other circumstances being equal.

Nowadays, Occam’s razor is an established mental model which can form a useful part of a latticework of knowledge.

[<img alt="Mental Model Occam's Razor" src="https://149664534.v2.pressablecdn.com/wp-content/uploads/2017/05/occams-razor-white-300x300.jpg" height="300" width="300" />](https://149664534.v2.pressablecdn.com/wp-content/uploads/2017/05/occams-razor-white.jpg)

## Examples of the Use of Occam’s Razor

**The Development of Scientific Theories**

Occam’s razor is frequently used by scientists, in particular for theoretical matters. The simpler a hypothesis is, the more easily it can be proven or falsified. A complex explanation for a phenomenon involves many factors which can be difficult to test or lead to issues with the repeatability of an experiment. As a consequence, the simplest solution which is consistent with the existing data is preferred. However, it is common for new data to allow hypotheses to become more complex over time. Scientists choose to opt for the simplest solution as the current data permits, while remaining open to the possibility of future research allowing for greater complexity.

The version used by scientists can best be summarized as:

_When you have two competing theories that make exactly the same predictions, the simpler one is better._

The use of Occam’s razor in science is also a matter of practicality. Obtaining funding for simpler hypotheses tends to be easier, as they are often cheaper to prove.

[Albert Einstein](https://fs.blog/2014/12/albert-einstein-simplicity/) referred to Occam’s razor when developing his theory of special relativity. He formulated his own version: “It can scarcely be denied that the supreme goal of all theory is to make the irreducible basic elements as simple and as few as possible without having to surrender the adequate representation of a single datum of experience.” Or, “Everything should be made as simple as possible, but not simpler.”

The physicist [Stephen Hawking](https://fs.blog/2015/05/stephen-hawking-explains-origin-universe/) advocates for Occam’s razor in [_A Brief History of Time_](https://www.amazon.com/gp/product/0553380168/ref=as_li_qf_sp_asin_il_tl?ie=UTF8&tag=farnamstreet-20&camp=1789&creative=9325&linkCode=as2&creativeASIN=0553380168&linkId=184c52e6213e272db3e16b4ddc43b19d):

> We could still imagine that there is a set of laws that determines events completely for some supernatural being, who could observe the present state of the universe without disturbing it. However, such models of the universe are not of much interest to us mortals. It seems better to employ the principle known as Occam’s razor and cut out all the features of the theory that cannot be observed.

Isaac Newton used Occam’s razor too when developing his theories. Newton stated: “We are to admit no more causes of natural things than such as are both true and sufficient to explain their appearances.” He sought to make his theories, including the three laws of motion, as simple as possible, with only the necessary minimum of underlying assumptions.

**Medicine**

Modern doctors use a version of Occam’s razor, stating that they should look for the fewest possible causes to explain their patient’s multiple symptoms, and give preference to the most likely causes. A doctor we know often repeats the aphorism that “common things are common.” Interns are instructed, “when you hear hoofbeats, think horses, not zebras.” For example, a person displaying influenza-like symptoms during an epidemic would be considered more likely to be suffering from influenza than an alternative, rarer disease. Making minimal diagnoses reduces the risk of over-treating a patient, causing panic, or causing dangerous interactions between different treatments. This is of particular importance within the current medical model, where patients are likely to see numerous health specialists and communication between them can be poor.

**Prison Abolition and Fair Punishment**

Occam’s razor has long played a role in attitudes towards the punishment of crimes. In this context, it refers to the idea that people should be given the least punishment necessary for their crimes. This is to avoid the excessive penal practices which were popular in the past. For example, a 19<sup>th</sup>-century English convict could receive five years of hard labor for stealing a piece of food.

The concept of penal parsimony was pioneered by Jeremy Bentham, the founder of utilitarianism. He held that punishments should not cause more pain than they prevent. Life imprisonment for murder could be seen as justified in that it might prevent a great deal of potential pain, should the perpetrator offend again. On the other hand, long-term imprisonment of an impoverished person for stealing food causes substantial suffering without preventing any.

Bentham’s writings on the application of Occam’s razor to punishment led to the prison abolition movement and many modern ideas related to rehabilitation.

**Exceptions and Issues**

It is important to note that, like any mental model, Occam’s razor is not foolproof. Use it with care, lest you cut yourself. This is especially crucial when it comes to important or risky decisions. There are exceptions to any rule, and **we should never blindly follow the results of applying a mental model which logic, experience, or empirical evidence contradict**. When you hear hoofbeats behind you, in most cases you should think horses, not zebras—unless you are out on the African savannah.

Furthermore, simple is as simple does. A conclusion can’t rely just on its simplicity. It must be backed by empirical evidence. And when using Occam’s razor to make deductions, we must avoid falling prey to confirmation bias. In the case of the NASA moon landing conspiracy theory, for example, some people consider it simpler for the moon landing to have been faked, others for it to have been real. Lisa Randall best expressed the issues with the narrow application of Occam’s razor in her book, [_Dark Matter and the Dinosaurs: The Astounding Interconnectedness of the Universe_](https://www.amazon.com/gp/product/0062328476/ref=as_li_qf_sp_asin_il_tl?ie=UTF8&tag=farnamstreet-20&camp=1789&creative=9325&linkCode=as2&creativeASIN=0062328476&linkId=fbaf8fe155fb6142b8c99300984afec6):

Another concern about Occam’s Razor is just a matter of fact. The world is more complicated than any of us would have been likely to conceive. Some particles and properties don’t seem necessary to any physical processes that matter—at least according to what we’ve deduced so far. Yet they exist. Sometimes the simplest model just isn’t the correct one.

This is why it’s important to remember that **opting for simpler explanations still requires work**. They may be easier to falsify, but still require effort. And that the simpler explanation, although having a higher chance of being correct, is not always true.

Occam’s razor is not intended to be a substitute for critical thinking. It is merely a tool to help make that thinking more efficient. Harlan Coben has disputed many criticisms of Occam’s razor by stating that people fail to understand its exact purpose:

> Most people oversimplify Occam’s razor to mean the simplest answer is usually correct. But the real meaning, what the Franciscan friar William of Ockham really wanted to emphasize, is that you shouldn’t complicate, that you shouldn’t “stack” a theory if a simpler explanation was at the ready. Pare it down. Prune the excess.

Remember, Occam’s razor is complemented by other mental models, including [fundamental error distribution](https://fs.blog/2016/08/fundamental-attribution-error/), [Hanlon’s razor](https://fs.blog/2017/04/mental-model-hanlons-razor/), [confirmation bias](https://fs.blog/2017/05/confirmation-bias/), [availability heuristic](https://fs.blog/2011/08/mental-model-availability-bias/) and [hindsight bias](https://fs.blog/2009/08/what-is-hindsight-bias/). The nature of mental models is that they tend to all interlock and work best in conjunction.
